@@ -1,3 +1,4 @@
+from .addmissingdates import AddMissingDatesStep
 from .aggregate import AggregateStep
 from .append import AppendStep
 from .argmax import ArgmaxStep
@@ -10,6 +11,7 @@ from .date_extract import DateExtractStep
 from .delete import DeleteStep
 from .domain import DomainStep
 from .duplicate import DuplicateStep
+from .duration import DurationStep
 from .evolution import EvolutionStep
 from .fillna import FillnaStep
 from .filter import FilterStep
