@@ -10,8 +10,5 @@ class RenameStep(BaseStep):
     name = Field('rename', const=True)
     to_rename: List[Tuple[str, str]] = Field(..., alias='toRename')
 
-    class Config:
-        allow_population_by_field_name = True
-
     def execute(self, df: DataFrame, domain_retriever=None, execute_pipeline=None) -> DataFrame:
         return df.rename(columns=dict(self.to_rename))
